@@ -52,9 +52,16 @@ if verbose:
 yb = yum.YumBase ()
 yb.preconf.debuglevel = verbose
 yb.preconf.errorlevel = verbose
+try:
+    yb.prerepoconf.multi_progressbar = None
+except:
+    pass
 if %s:
     yb.preconf.fn = %S
-yb.setCacheDir ()
+try:
+    yb.setCacheDir ()
+except AttributeError:
+    pass
 
 if verbose:
     print \"febootstrap_yum_rpm: looking up the base packages from the command line\"
@@ -125,10 +132,6 @@ if verbose:
     )
     else pkgs in
 
-  (* Drop the kernel package to save time. *)
-  let pkgs =
-    List.filter (function ("kernel",_,_,_,_) -> false | _ -> true) pkgs in
-
   (* Exclude packages matching [--exclude] regexps on the command line. *)
   let pkgs =
     List.filter (
